--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1112','helmert_transformation','EPSG','1672','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1154','helmert_transformation','EPSG','1304','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1232','helmert_transformation','EPSG','1305','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1236','helmert_transformation','EPSG','1280','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1236','helmert_transformation','EPSG','1669','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1297','helmert_transformation','EPSG','1298','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1297','helmert_transformation','EPSG','1299','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1297','helmert_transformation','EPSG','1300','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1297','helmert_transformation','EPSG','1301','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1320','helmert_transformation','EPSG','1326','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1321','helmert_transformation','EPSG','1324','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1322','helmert_transformation','EPSG','1324','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1324','helmert_transformation','EPSG','1327','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1325','helmert_transformation','EPSG','1327','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1330','helmert_transformation','EPSG','1557','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1437','helmert_transformation','EPSG','1895','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','1451','grid_transformation','EPSG','1575','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1459','helmert_transformation','EPSG','1594','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','1464','grid_transformation','EPSG','1596','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','1506','grid_transformation','EPSG','1803','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','1507','grid_transformation','EPSG','1803','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','1559','grid_transformation','EPSG','1593','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','1593','grid_transformation','EPSG','1804','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','1596','grid_transformation','EPSG','1803','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1655','helmert_transformation','EPSG','1997','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1657','helmert_transformation','EPSG','1992','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1674','helmert_transformation','EPSG','1775','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1680','helmert_transformation','EPSG','1896','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1683','helmert_transformation','EPSG','1684','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1683','helmert_transformation','EPSG','1685','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1683','helmert_transformation','EPSG','1686','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1683','helmert_transformation','EPSG','1687','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1807','helmert_transformation','EPSG','1808','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1900','helmert_transformation','EPSG','1901','EPSG');
INSERT INTO "supersession" VALUES('concatenated_operation','EPSG','8047','concatenated_operation','EPSG','8569','EPSG');
INSERT INTO "supersession" VALUES('concatenated_operation','EPSG','8047','helmert_transformation','EPSG','1612','EPSG');
INSERT INTO "supersession" VALUES('concatenated_operation','EPSG','8569','helmert_transformation','EPSG','1612','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1638','helmert_transformation','EPSG','10098','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1639','helmert_transformation','EPSG','10099','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1751','helmert_transformation','EPSG','15739','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1066','helmert_transformation','EPSG','15740','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','15781','grid_transformation','EPSG','10084','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15791','helmert_transformation','EPSG','1330','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15817','helmert_transformation','EPSG','15818','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15852','grid_transformation','EPSG','15851','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15853','grid_transformation','EPSG','15851','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15854','grid_transformation','EPSG','15851','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15856','grid_transformation','EPSG','15851','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1309','helmert_transformation','EPSG','1776','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1673','helmert_transformation','EPSG','1777','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1753','helmert_transformation','EPSG','1766','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','15895','grid_transformation','EPSG','15932','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','15907','grid_transformation','EPSG','15933','EPSG');
INSERT INTO "supersession" VALUES('concatenated_operation','EPSG','8581','helmert_transformation','EPSG','1439','EPSG');
INSERT INTO "supersession" VALUES('concatenated_operation','EPSG','8657','helmert_transformation','EPSG','15846','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1672','helmert_transformation','EPSG','15934','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1829','helmert_transformation','EPSG','1449','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1830','helmert_transformation','EPSG','1448','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1831','helmert_transformation','EPSG','1242','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15993','helmert_transformation','EPSG','15994','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1656','helmert_transformation','EPSG','1988','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1658','helmert_transformation','EPSG','1987','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1928','helmert_transformation','EPSG','15901','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15783','helmert_transformation','EPSG','15901','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1917','helmert_transformation','EPSG','15902','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1927','helmert_transformation','EPSG','15902','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1962','helmert_transformation','EPSG','15903','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1963','helmert_transformation','EPSG','15903','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','3972','helmert_transformation','EPSG','4834','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','10092','helmert_transformation','EPSG','5051','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1992','helmert_transformation','EPSG','5037','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1281','helmert_transformation','EPSG','5043','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1267','helmert_transformation','EPSG','5044','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1997','helmert_transformation','EPSG','5038','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1550','helmert_transformation','EPSG','5061','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1551','helmert_transformation','EPSG','5061','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1552','helmert_transformation','EPSG','5061','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15710','helmert_transformation','EPSG','5053','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15711','helmert_transformation','EPSG','5051','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15712','helmert_transformation','EPSG','5055','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','10091','helmert_transformation','EPSG','5055','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','10089','helmert_transformation','EPSG','5051','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','10090','helmert_transformation','EPSG','5053','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15872','helmert_transformation','EPSG','5078','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1642','helmert_transformation','EPSG','5485','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1643','helmert_transformation','EPSG','5486','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15754','helmert_transformation','EPSG','5055','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15754','helmert_transformation','EPSG','5053','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15754','helmert_transformation','EPSG','5051','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','10093','helmert_transformation','EPSG','5055','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','10093','helmert_transformation','EPSG','5053','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','10093','helmert_transformation','EPSG','5051','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1079','helmert_transformation','EPSG','5484','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1078','helmert_transformation','EPSG','5483','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10082','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1108','helmert_transformation','EPSG','6905','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10081','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10078','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10039','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10040','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10041','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10042','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10043','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','6392','helmert_transformation','EPSG','6279','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1121','helmert_transformation','EPSG','6906','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10083','grid_transformation','EPSG','5657','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','6315','helmert_transformation','EPSG','6278','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','6313','helmert_transformation','EPSG','6280','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1256','helmert_transformation','EPSG','6908','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1951','helmert_transformation','EPSG','6909','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','5662','helmert_transformation','EPSG','6939','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15938','helmert_transformation','EPSG','6998','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10000','grid_transformation','EPSG','8271','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15800','helmert_transformation','EPSG','6907','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','15897','helmert_transformation','EPSG','6895','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1868','helmert_transformation','EPSG','6976','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1868','helmert_transformation','EPSG','6975','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1868','helmert_transformation','EPSG','6974','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1203','helmert_transformation','EPSG','6971','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1204','helmert_transformation','EPSG','6973','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10063','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10037','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10064','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10066','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10067','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10068','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10069','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','5334','grid_transformation','EPSG','7718','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','5335','grid_transformation','EPSG','7719','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10001','grid_transformation','EPSG','8271','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10058','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10059','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10060','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10061','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10062','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1646','grid_transformation','EPSG','7674','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10034','grid_transformation','EPSG','7713','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10070','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10031','grid_transformation','EPSG','7713','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10030','grid_transformation','EPSG','7713','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10026','grid_transformation','EPSG','7713','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10071','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10025','grid_transformation','EPSG','7713','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10024','grid_transformation','EPSG','7713','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10072','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10033','grid_transformation','EPSG','7715','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10032','grid_transformation','EPSG','7716','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10021','grid_transformation','EPSG','7711','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10029','grid_transformation','EPSG','7712','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1766','grid_transformation','EPSG','7788','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10027','grid_transformation','EPSG','7714','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10023','grid_transformation','EPSG','7717','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10002','grid_transformation','EPSG','8272','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10073','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10038','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10074','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10035','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10044','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10045','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10046','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10047','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10048','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10049','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10050','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10051','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10052','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10053','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10036','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10054','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10055','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10056','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10057','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10075','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10076','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','5338','grid_transformation','EPSG','7709','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','5339','grid_transformation','EPSG','7710','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10077','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10079','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10080','grid_transformation','EPSG','5656','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','10003','grid_transformation','EPSG','8272','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','1923','helmert_transformation','EPSG','8270','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','4829','concatenated_operation','EPSG','8443','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','4827','concatenated_operation','EPSG','8443','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','4827','concatenated_operation','EPSG','8442','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','4829','concatenated_operation','EPSG','8442','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','5504','grid_transformation','EPSG','9135','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','5502','grid_transformation','EPSG','9136','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','8371','grid_transformation','EPSG','8885','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','3917','helmert_transformation','EPSG','8688','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','3915','helmert_transformation','EPSG','8688','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','3916','helmert_transformation','EPSG','8689','EPSG');
INSERT INTO "supersession" VALUES('helmert_transformation','EPSG','3914','helmert_transformation','EPSG','8689','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','5506','grid_transformation','EPSG','9134','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','5503','grid_transformation','EPSG','9133','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','5505','grid_transformation','EPSG','9188','EPSG');
INSERT INTO "supersession" VALUES('grid_transformation','EPSG','5508','grid_transformation','EPSG','9187','EPSG');
